==> rill-0.0.18.tgz: package/server/application.js <==
/** Rill v0.0.18 https://www.npmjs.com/package/rill License: MIT*/
var Application, Repsonse, Request, co, compose, hijack, http, parseDates, pathToReg, serverResponse,
  slice = [].slice;

co = require("co");

pathToReg = require("path-to-regexp");

compose = require("./util/compose");

parseDates = require("./util/parseDates");

Request = require("./request");

Repsonse = require("./response");

{
  http = require("http");
  serverResponse = require("./util/serverResponse");
}

Application = (function() {
  var j, len, method, ref;

  function Application() {
    if (!(this instanceof Application)) {
      return new Application();
    }
    this.middleware = [];
  }

  Application.prototype.listen = function() {
    var server;
    {
      server = http.createServer(this.callback());
      return server.listen.apply(server, arguments);
    }
  };

  Application.prototype.callback = function() {
    var fn;
    fn = co.wrap(compose(([serverResponse]).concat(this.middleware)));
    return function(req, res) {
      return fn(new Request(req), new Response(res));
    };
  };

  Application.prototype.use = function() {
    var middlewares;
    middlewares = 1 <= arguments.length ? slice.call(arguments, 0) : [];
    return this.middleware = this.middleware.concat(middlewares);
  };

  ref = ["options", "head", "get", "put", "post", "delete"];
  for (j = 0, len = ref.length; j < len; j++) {
    method = ref[j];
    Application.prototype[method] = (function() {
      return function() {
        var keys, middlewares, path;
        path = arguments[0], middlewares = 2 <= arguments.length ? slice.call(arguments, 1) : [];
        keys = [];
        path = pathToReg(path, keys);
        middlewares = compose(middlewares);
        return this.use(function*(req, res, next) {
          var i, k, len1, match, name;
          if (!(req.method === method && (match = req.pathname.match(path.regex)))) {
            return;
          }
          req.params = {};
          for (i = k = 0, len1 = keys.length; k < len1; i = ++k) {
            name = keys[i].name;
            req.params[name] = match[i + 1];
          }
          return (yield middlewares.call(this, req, res));
        });
      };
    })();
  }

  return Application;

})();

module.exports = Application;

==> rill-0.0.19.tgz: package/server/application.js <==
/** Rill v0.0.19 https://www.npmjs.com/package/rill License: MIT*/
var Application, Request, Response, co, compose, hijack, http, parseDates, pathToReg, serverResponse,
  slice = [].slice;

co = require("co");

pathToReg = require("path-to-regexp");

compose = require("./util/compose");

parseDates = require("./util/parseDates");

Request = require("./request");

Response = require("./response");

{
  http = require("http");
  serverResponse = require("./util/serverResponse");
}

Application = (function() {
  var j, len, method, ref;

  function Application() {
    if (!(this instanceof Application)) {
      return new Application();
    }
    this.middleware = [];
  }

  Application.prototype.listen = function() {
    var server;
    {
      server = http.createServer(this.callback());
      return server.listen.apply(server, arguments);
    }
  };

  Application.prototype.callback = function() {
    var fn;
    fn = co.wrap(compose(([serverResponse]).concat(this.middleware)));
    return function(req, res) {
      return fn(new Request(req), new Response(res));
    };
  };

  Application.prototype.use = function() {
    var middlewares;
    middlewares = 1 <= arguments.length ? slice.call(arguments, 0) : [];
    return this.middleware = this.middleware.concat(middlewares);
  };

  ref = ["options", "head", "get", "put", "post", "delete"];
  for (j = 0, len = ref.length; j < len; j++) {
    method = ref[j];
    Application.prototype[method] = (function() {
      return function() {
        var keys, middlewares, path;
        path = arguments[0], middlewares = 2 <= arguments.length ? slice.call(arguments, 1) : [];
        keys = [];
        path = pathToReg(path, keys);
        middlewares = compose(middlewares);
        return this.use(function*(req, res, next) {
          var i, k, len1, match, name;
          if (!(req.method === method && (match = req.pathname.match(path.regex)))) {
            return;
          }
          req.params = {};
          for (i = k = 0, len1 = keys.length; k < len1; i = ++k) {
            name = keys[i].name;
            req.params[name] = match[i + 1];
          }
          return (yield middlewares.call(this, req, res));
        });
      };
    })();
  }

  return Application;

})();

module.exports = Application;
